@@ -86,6 +86,38 @@ def interative_flirt(anat_file, anat_file_BET, template_brain_file,
     return anat_file_brain, template_to_anat_file
 
 
+# animal_warper
+def animal_warper(T1_file, NMT_SS_file):
+
+    import os
+    from nipype.utils.filemanip import split_filename as split_f
+
+    path, fname, ext = split_f(T1_file)
+
+    os.chdir(os.path.abspath(""))
+
+    cmd = "@animal_warper -input {} -base {}".format(T1_file, NMT_SS_file)
+
+    print("cmd")
+
+    os.system(cmd)
+
+    res_path = os.path.abspath("aw_results")
+
+    aff_file = os.path.join(res_path, fname + "_ns" + ext)
+
+    warp_file = os.path.join(res_path, fname + "_shft_WARP" + ext)
+    warpinv_file = os.path.join(res_path, fname + "_shft_WARPINV" + ext)
+
+    transfo_file = os.path.join(
+        res_path, fname + "_composite_linear_to_template.1D")
+    inv_transfo_file = os.path.join(
+        res_path, fname + "_composite_linear_to_template_inv.1D")
+
+    return (aff_file, warp_file, warpinv_file,
+            transfo_file, inv_transfo_file)
+
+
 # IterREGBET
 class IterREGBETInputSpec(CommandLineInputSpec):
 
@@ -260,8 +292,10 @@ class IterREGBET(CommandLine):
     input_spec = IterREGBETInputSpec
     output_spec = IterREGBETOutputSpec
 
-    package_directory = os.path.dirname(os.path.abspath(__file__))
-    _cmd = 'bash {}/../bash/IterREGBET.sh'.format(package_directory)
+    path_to_current_dir = os.path.dirname(os.path.abspath(__file__))
+    package_directory = os.path.dirname(path_to_current_dir)
+
+    _cmd = 'bash {}/bash/IterREGBET.sh'.format(package_directory)
 
     def _gen_filename(self, name):
         if name == "xp":
@@ -380,8 +414,10 @@ class NMTSubjectAlign(CommandLine):
     input_spec = NMTSubjectAlignInputSpec
     output_spec = NMTSubjectAlignOutputSpec
 
-    package_directory = os.path.dirname(os.path.abspath(__file__))
-    _cmd = 'tcsh -x {}/../bash/NMT_subject_align.csh'.format(package_directory)
+    path_to_current_dir = os.path.dirname(os.path.abspath(__file__))
+    package_directory = os.path.dirname(path_to_current_dir)
+
+    _cmd = 'tcsh -x {}/bash/NMT_subject_align.csh'.format(package_directory)
 
     def _list_outputs(self):
 
@@ -488,8 +524,10 @@ class NMTSubjectAlign2(CommandLine):
     input_spec = NMTSubjectAlign2InputSpec
     output_spec = NMTSubjectAlign2OutputSpec
 
-    package_directory = os.path.dirname(os.path.abspath(__file__))
-    _cmd = 'bash {}/../bash/NMT_subject_align'.format(package_directory)
+    path_to_current_dir = os.path.dirname(os.path.abspath(__file__))
+    package_directory = os.path.dirname(path_to_current_dir)
+
+    _cmd = 'bash {}/bash/NMT_subject_align'.format(package_directory)
 
     def _list_outputs(self):
 
@@ -628,7 +666,11 @@ class NwarpApplyPriors(AFNICommandBase):
 
             else:
                 print("Not a list for in_file {}".format(value))
-                shutil.copy(value, cur_dir)
+                print(os.listdir(cur_dir))
+                print(value)
+
+                if value not in os.listdir(cur_dir):
+                    shutil.copy(value, cur_dir)
 
                 path, fname, ext = split_f(value)
                 new_value = os.path.join(cur_dir, fname + ext)
