@@ -28,7 +28,7 @@
 
     Example
     ---------
-    python segment_kepkee.py -data [PATH_TO_BIDS] -out ../local_tests/ -subjects Elouk
+    python segment_pnh.py -data [PATH_TO_BIDS] -out ../local_tests/ -subjects Elouk
 
     Requirements
     --------------
@@ -71,6 +71,7 @@ from macapype.utils.utils_bids import (create_datasource, create_datasource_indi
 from macapype.utils.utils_tests import load_test_data, format_template
 
 from macapype.utils.utils_nodes import node_output_exists
+from macapype.utils.utils_params import update_params
 
 from macapype.utils.misc import show_files, get_first_elem, parse_key
 
@@ -78,8 +79,8 @@ from macapype.utils.misc import show_files, get_first_elem, parse_key
 
 def create_main_workflow(data_dir, process_dir, soft, species, subjects, sessions,
                          acquisitions, reconstructions, params_file,
-                         indiv_params_file, mask_file, nprocs,
-                         wf_name="macapype",
+                         indiv_params_file, mask_file, template_path,
+                         template_files, nprocs, wf_name="macapype",
                          deriv=False, pad=False):
 
     # macapype_pipeline
@@ -107,6 +108,9 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
     acquisitions: list of str (optional)
         Acquisition name to match to BIDS specification (acq-[ACQ1]...)
 
+    reconstructions: list of str (optional)
+        Reconstructions name to match to BIDS specification (rec-[ACQ1]...)
+
     indiv_params_file: path to a JSON file
         JSON file that specify some parameters of the pipeline,
         unique for the subjects/sessions.
@@ -114,6 +118,9 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
     params_file: path to a JSON file
         JSON file that specify some parameters of the pipeline.
 
+    nprocs: integer
+        number of processes that will be launched by MultiProc
+
 
     Returns
     -------
@@ -134,6 +141,9 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
     if 'prep' in ssoft:
         new_ssoft.remove('prep')
 
+    if 'noseg' in ssoft:
+        new_ssoft.remove('noseg')
+
     if 't1' in ssoft:
         new_ssoft.remove('t1')
 
@@ -143,29 +153,28 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
     if 'template' in ssoft:
         new_ssoft.remove('template')
 
-
     soft = "_".join(new_ssoft)
 
     # formating args
     data_dir = op.abspath(data_dir)
 
+    process_dir = op.abspath(process_dir)
 
     try:
         os.makedirs(process_dir)
+
     except OSError:
         print("process_dir {} already exists".format(process_dir))
 
-    # species
-    # params
-    params = {}
-
+    #params
     if params_file is None:
 
+        # species
         if species is not None:
 
             species = species.lower()
 
-            rep_species = {"marmoset":"marmo", "chimpanzee":"chimp"}
+            rep_species = {"marmoset":"marmo", "marmouset":"marmo", "chimpanzee":"chimp"}
 
             if species in list(rep_species.keys()):
                 species = rep_species[species]
@@ -176,7 +185,7 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
                 "Error, species {} should in the following list {}".format(
                     species, list_species)
 
-            package_directory = os.path.dirname(os.path.abspath(__file__))
+            package_directory = op.dirname(op.abspath(__file__))
 
             params_file = "{}/params_segment_{}_{}.json".format(
                 package_directory, species, soft)
@@ -186,178 +195,38 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
                 other is mandatory)")
             exit(-1)
 
-    print("Params:", params_file)
+        print("Using default params file:", params_file)
 
-    assert os.path.exists(params_file), "Error with file {}".format(
-        params_file)
-
-    params = json.load(open(params_file))
-
-    # indiv_params
-    indiv_params = {}
-
-    if indiv_params_file is None:
-
-        print("No indiv params where found, modifing pipepline to default")
-
-        if "short_preparation_pipe" in params.keys():
-            if "crop_T1" in params["short_preparation_pipe"].keys():
-                print("Deleting crop_T1")
-                del params["short_preparation_pipe"]["crop_T1"]
-
-                print("Adding automated bet_crop")
-
-                params["short_preparation_pipe"]["bet_crop"] = {"m": True, "aT2": True, "c": 10, "n": 2}
-
-                print("Using default bet_crop parameters: {}".format(
-                    params["short_preparation_pipe"]["bet_crop"]))
-
-                print("New params after modification")
-                pprint.pprint(params)
-
-                wf_name+="_bet_crop"
+        params, indiv_params, extra_wf_name = update_params(ssoft=ssoft, subjects=subjects, sessions=sessions,
+                            params_file=params_file, indiv_params_file=indiv_params_file)
 
     else:
 
-        indiv_params = json.load(open(indiv_params_file))
+        # format for relative path
+        params_file = op.abspath(params_file)
 
-        wf_name+="_indiv_params"
+        # params
+        assert op.exists(params_file), "Error with file {}".format(
+            params_file)
 
-        pprint.pprint(indiv_params)
+        print("Using orig params file:", params_file)
 
-        if "short_preparation_pipe" not in params.keys():
+        params = json.load(open(params_file))
 
-            print("short_preparation_pipe not found in params, not modifying preparation pipe")
+        extra_wf_name = "_orig"
+        indiv_params = {}
 
-        else:
+        # indiv_params
+        if indiv_params_file is not None:
 
-            prep_pipe = "short_preparation_pipe"
-            count_all_sessions=0
-            count_T1_crops=0
-            count_long_crops=0
-            count_multi_long_crops=0
+            # format for relative path
+            indiv_params_file = op.abspath(indiv_params_file)
 
-            print("Indiv Params:", indiv_params_file)
-
-            assert os.path.exists(indiv_params_file), "Error with file {}".format(
+            assert op.exists(indiv_params_file), "Error with file {}".format(
                 indiv_params_file)
+            indiv_params = json.load(open(indiv_params_file))
 
-            if subjects is None or sessions is None:
-                print("For whole BIDS dir, unable to assess if the indiv_params is correct")
-                print("Running with params as it is")
-
-            else:
-
-                print("Will modify params if necessary, given specified subjects and sessions;\n")
-
-                for sub in indiv_params.keys():
-
-                    if sub.split('-')[1] not in subjects:
-                        continue
-
-                    for ses in indiv_params[sub].keys():
-
-                        if ses.split('-')[1] not in sessions:
-                            continue
-
-                        count_all_sessions+=1
-
-                        print (indiv_params[sub][ses].keys())
-
-                        if "crop_T1" in indiv_params[sub][ses].keys():
-                            count_T1_crops+=1
-
-                            if "crop_T2" in indiv_params[sub][ses].keys() \
-                                and 't1' not in ssoft:
-
-                                count_long_crops+=1
-
-                                if isinstance(
-                                    indiv_params[sub][ses]["crop_T1"]["args"],
-                                    list) and isinstance(
-                                        indiv_params[sub][ses]["crop_T2"]["args"],
-                                        list):
-
-                                    count_multi_long_crops+=1
-
-                print("count_all_sessions {}".format(count_all_sessions))
-
-                print("count_T1_crops {}".format(count_T1_crops))
-                print("count_long_crops {}".format(count_long_crops))
-                print("count_multi_long_crops {}".format(count_multi_long_crops))
-
-                if count_multi_long_crops==count_all_sessions:
-                    print("**** Found list of crops for T1 and T2 for all sub/ses \
-                        in indiv -> long_multi_preparation_pipe")
-
-                    prep_pipe = "long_multi_preparation_pipe"
-
-                    wf_name+="_long_multi"
-
-                elif count_long_crops==count_all_sessions:
-
-                    print("**** Found crop for T1 and crop for T2 for all sub/ses \
-                        in indiv -> long_single_preparation_pipe")
-
-                    prep_pipe = "long_single_preparation_pipe"
-
-                    wf_name+="_long_single"
-
-                elif count_T1_crops==count_all_sessions:
-
-                    print("**** Found crop for T1 for all sub/ses in indiv \
-                        -> keeping short_preparation_pipe")
-
-                else:
-                    print("**** not all sub/ses have T1 and T2 crops ")
-                    print("Error")
-                    exit(0)
-
-                if prep_pipe != "short_preparation_pipe":
-
-                    params[prep_pipe]={
-                        "prep_T1": {"crop_T1": {"args": "should be defined in indiv"}},
-                        "prep_T2": {"crop_T2": {"args": "should be defined in indiv"}},
-                        "align_T2_on_T1": {"dof": 6, "cost": "normmi"}}
-
-                    if "denoise" in params["short_preparation_pipe"].keys():
-                        denoise= params["short_preparation_pipe"]["denoise"]
-
-                        params[prep_pipe]["prep_T1"]["denoise"]=denoise
-                        params[prep_pipe]["prep_T2"]["denoise"]=denoise
-
-                    del params["short_preparation_pipe"]
-
-    # prep for testing only preparation part
-    if "prep" in ssoft:
-        print("Found prep in soft")
-
-        if "brain_extraction_pipe" in params.keys():
-            del params["brain_extraction_pipe"]
-            print("Deleting brain_extraction_pipe")
-
-
-        if "brain_segment_pipe" in params.keys():
-            del params["brain_segment_pipe"]
-            print("Deleting brain_segment_pipe")
-
-    pprint.pprint(params)
-
-    # params_template
-    assert ("general" in params.keys() and \
-        "template_name" in params["general"].keys()), \
-            "Error, the params.json should contains a general/template_name"
-
-    template_name = params["general"]["template_name"]
-
-    if "general" in params.keys() and "my_path" in params["general"].keys():
-        my_path = params["general"]["my_path"]
-    else:
-        my_path = ""
-
-    nmt_dir = load_test_data(template_name, path_to = my_path)
-    params_template = format_template(nmt_dir, template_name)
-    print (params_template)
+    wf_name += extra_wf_name
 
     # soft
     wf_name += "_{}".format(soft)
@@ -371,35 +240,126 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
     assert "spm" in ssoft or "spm12" in ssoft or "ants" in ssoft, \
         "error with {}, should be among [spm12, spm, ants]".format(ssoft)
 
+    # adding forced space
+    if "spm" in ssoft or "spm12" in ssoft:
+        if 'native' in ssoft:
+            wf_name += "_native"
+
+    elif "ants" in ssoft:
+        if "template" in ssoft:
+            wf_name += "_template"
+
+    # params_template
+    if template_path is not None:
+
+        # format for relative path
+        template_path = op.abspath(template_path)
+
+        assert os.path.exists(template_path), "Error, template_path {} do not exists".format(template_path)
+
+        print(template_files)
+
+        params_template = {}
+
+        assert len(template_files) > 1, "Error, template_files unspecified {}".format(template_files)
+
+        template_head = os.path.join(template_path,template_files[0])
+        assert os.path.exists(template_head), "Could not find template_head {}".format(template_head)
+        params_template["template_head"] = template_head
+
+        template_brain = os.path.join(template_path,template_files[1])
+        assert os.path.exists(template_brain), "Could not find template_brain {}".format(template_brain)
+        params_template["template_brain"] = template_brain
+
+        if len(template_files) == 3:
+
+            template_seg = os.path.join(template_path,template_files[2])
+            assert os.path.exists(template_seg), "Could not find template_seg {}".format(template_seg)
+            params_template["template_seg"] = template_seg
+
+        elif len(template_files) == 5:
+
+            template_gm = os.path.join(template_path,template_files[2])
+            assert os.path.exists(template_gm), "Could not find template_gm {}".format(template_gm)
+            params_template["template_gm"] = template_gm
+
+            template_wm = os.path.join(template_path,template_files[3])
+            assert os.path.exists(template_wm), "Could not find template_wm {}".format(template_wm)
+            params_template["template_wm"] = template_wm
+
+            template_csf = os.path.join(template_path,template_files[4])
+            assert os.path.exists(template_csf), "Could not find template_csf {}".format(template_csf)
+            params_template["template_csf"] = template_csf
+
+        else:
+            print("Unknown template_files format, should be 3 or 5 files")
+            exit(-1)
+
+    else:
+        ### use template from params
+        assert ("general" in params.keys() and \
+            "template_name" in params["general"].keys()), \
+                "Error, the params.json should contains a general/template_name"
+
+        template_name = params["general"]["template_name"]
+
+        if "general" in params.keys() and "my_path" in params["general"].keys():
+            my_path = params["general"]["my_path"]
+        else:
+            my_path = ""
+
+        template_dir = load_test_data(template_name, path_to = my_path)
+        params_template = format_template(template_dir, template_name)
+
+        if "template_aladin_name" in params["general"].keys():
+
+            template_aladin_name = params["general"]["template_aladin_name"]
+            template_aladin_dir = load_test_data(template_aladin_name, path_to = my_path)
+            params_template_aladin = format_template(template_aladin_dir, template_aladin_name)
+
+        else:
+            params_template_aladin = params_template
+
+
+
+
+    print (params_template)
+
     # main_workflow
     main_workflow = pe.Workflow(name= wf_name)
 
     main_workflow.base_dir = process_dir
 
+    # which soft is used
     if "spm" in ssoft or "spm12" in ssoft:
         if 'native' in ssoft:
             space='native'
+
         else:
             space='template'
 
         segment_pnh_pipe = create_full_spm_subpipes(
-            params_template=params_template, params=params, pad=pad,
-            space=space)
+            params_template=params_template,
+            params_template_aladin=params_template_aladin,
+            params=params, pad=pad, space=space)
 
     elif "ants" in ssoft:
         if "template" in ssoft:
             space="template"
+
         else:
             space="native"
 
         if "t1" in ssoft:
             segment_pnh_pipe = create_full_T1_ants_subpipes(
-                params_template=params_template, params=params, space=space,
-                pad=pad)
+                params_template=params_template,
+                params_template_aladin=params_template_aladin,
+                params=params, space=space, pad=pad)
         else:
             segment_pnh_pipe = create_full_ants_subpipes(
-                params_template=params_template, params=params,
-                mask_file=mask_file, space=space, pad=pad)
+                params_template=params_template,
+                params_template_aladin=params_template_aladin,
+                params=params, mask_file=mask_file, space=space, pad=pad)
 
     # list of all required outputs
     output_query = {}
@@ -537,12 +497,19 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
 
         datasink.inputs.base_directory = process_dir
 
+        if len(datasource.iterables) == 1:
+            pref_deriv = "sub-%(sub)s"
+            parse_str = r"sub-(?P<sub>\w*)_.*"
+        elif len(datasource.iterables) > 1:
+            pref_deriv = "sub-%(sub)s_ses-%(ses)s"
+            parse_str = r"sub-(?P<sub>\w*)_ses-(?P<ses>\w*)_.*"
+
         if "brain_extraction_pipe" in params.keys():
 
             ### rename brain_mask
             rename_brain_mask = pe.Node(niu.Rename(), name = "rename_brain_mask")
-            rename_brain_mask.inputs.format_string = "sub-%(sub)s_ses-%(ses)s_space-native_desc-brain_mask"
-            rename_brain_mask.inputs.parse_string = r"sub-(?P<sub>\w*)_ses-(?P<ses>\w*)_.*"
+            rename_brain_mask.inputs.format_string = pref_deriv + "_space-native_desc-brain_mask"
+            rename_brain_mask.inputs.parse_string = parse_str
             rename_brain_mask.inputs.keep_ext = True
 
             main_workflow.connect(
@@ -553,12 +520,40 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
                 rename_brain_mask, 'out_file',
                 datasink, '@brain_mask')
 
-        if "brain_segment_pipe" in params.keys():
+        elif "debias" in params.keys():
+
+            ### rename brain_mask
+            rename_brain_mask = pe.Node(niu.Rename(), name = "rename_brain_mask")
+            rename_brain_mask.inputs.format_string = pref_deriv + "_space-native_desc-brain_mask"
+            rename_brain_mask.inputs.parse_string = parse_str
+            rename_brain_mask.inputs.keep_ext = True
+
+            main_workflow.connect(
+                segment_pnh_pipe, 'outputnode.brain_mask',
+                rename_brain_mask, 'in_file')
+
+            main_workflow.connect(
+                rename_brain_mask, 'out_file',
+                datasink, '@brain_mask')
+
+            ### rename debiased_T1
+            rename_debiased_T1 = pe.Node(niu.Rename(), name = "rename_debiased_T1")
+            rename_debiased_T1.inputs.format_string = pref_deriv + "_space-native_desc-debiased_T1w"
+            rename_debiased_T1.inputs.parse_string = parse_str
+            rename_debiased_T1.inputs.keep_ext = True
+
+            main_workflow.connect(
+                segment_pnh_pipe, 'outputnode.debiased_T1',
+                rename_debiased_T1, 'in_file')
+
+            main_workflow.connect(
+                rename_debiased_T1, 'out_file',
+                datasink, '@debiased_T1')
 
             ### rename debiased_brain
             rename_debiased_brain = pe.Node(niu.Rename(), name = "rename_debiased_brain")
-            rename_debiased_brain.inputs.format_string = "sub-%(sub)s_ses-%(ses)s_space-native_desc-debiased_desc-brain_T1w"
-            rename_debiased_brain.inputs.parse_string = r"sub-(?P<sub>\w*)_ses-(?P<ses>\w*)_.*"
+            rename_debiased_brain.inputs.format_string = pref_deriv + "_space-native_desc-debiased_desc-brain_T1w"
+            rename_debiased_brain.inputs.parse_string = parse_str
             rename_debiased_brain.inputs.keep_ext = True
 
             main_workflow.connect(
@@ -569,12 +564,26 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
                 rename_debiased_brain, 'out_file',
                 datasink, '@debiased_brain')
 
+        if "brain_segment_pipe" in params.keys():
 
+            ### rename debiased_brain
+            rename_debiased_brain = pe.Node(niu.Rename(), name = "rename_debiased_brain")
+            rename_debiased_brain.inputs.format_string = pref_deriv + "_space-native_desc-debiased_desc-brain_T1w"
+            rename_debiased_brain.inputs.parse_string = parse_str
+            rename_debiased_brain.inputs.keep_ext = True
+
+            main_workflow.connect(
+                segment_pnh_pipe, 'outputnode.debiased_brain',
+                rename_debiased_brain, 'in_file')
+
+            main_workflow.connect(
+                rename_debiased_brain, 'out_file',
+                datasink, '@debiased_brain')
 
             ### rename debiased_T1
             rename_debiased_T1 = pe.Node(niu.Rename(), name = "rename_debiased_T1")
-            rename_debiased_T1.inputs.format_string = "sub-%(sub)s_ses-%(ses)s_space-native_desc-debiased_T1w"
-            rename_debiased_T1.inputs.parse_string = r"sub-(?P<sub>\w*)_ses-(?P<ses>\w*)_.*"
+            rename_debiased_T1.inputs.format_string = pref_deriv + "_space-native_desc-debiased_T1w"
+            rename_debiased_T1.inputs.parse_string = parse_str
             rename_debiased_T1.inputs.keep_ext = True
 
             main_workflow.connect(
@@ -587,8 +596,8 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
 
             ### rename segmented_brain_mask
             rename_segmented_brain_mask = pe.Node(niu.Rename(), name = "rename_segmented_brain_mask")
-            rename_segmented_brain_mask.inputs.format_string = "sub-%(sub)s_ses-%(ses)s_space-native_desc-brain_dseg"
-            rename_segmented_brain_mask.inputs.parse_string = r"sub-(?P<sub>\w*)_ses-(?P<ses>\w*)_.*"
+            rename_segmented_brain_mask.inputs.format_string = pref_deriv + "_space-{}_desc-brain_dseg".format(space)
+            rename_segmented_brain_mask.inputs.parse_string = parse_str
             rename_segmented_brain_mask.inputs.keep_ext = True
 
             main_workflow.connect(
@@ -602,8 +611,8 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
             ### rename prob_wm
             print("Renaming prob_wm file")
             rename_prob_wm = pe.Node(niu.Rename(), name = "rename_prob_wm")
-            rename_prob_wm.inputs.format_string = "sub-%(sub)s_ses-%(ses)s_space-{}_label-WM_probseg".format(space)
-            rename_prob_wm.inputs.parse_string = r"sub-(?P<sub>\w*)_ses-(?P<ses>\w*)_.*"
+            rename_prob_wm.inputs.format_string = pref_deriv + "_space-{}_label-WM_probseg".format(space)
+            rename_prob_wm.inputs.parse_string = parse_str
             rename_prob_wm.inputs.keep_ext = True
 
             main_workflow.connect(
@@ -617,8 +626,8 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
             ### rename prob_gm
             print("Renaming prob_gm file")
             rename_prob_gm = pe.Node(niu.Rename(), name = "rename_prob_gm")
-            rename_prob_gm.inputs.format_string = "sub-%(sub)s_ses-%(ses)s_space-{}_label-GM_probseg".format(space)
-            rename_prob_gm.inputs.parse_string = r"sub-(?P<sub>\w*)_ses-(?P<ses>\w*)_.*"
+            rename_prob_gm.inputs.format_string = pref_deriv + "_space-{}_label-GM_probseg".format(space)
+            rename_prob_gm.inputs.parse_string = parse_str
             rename_prob_gm.inputs.keep_ext = True
 
             main_workflow.connect(
@@ -632,8 +641,8 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
             ### rename prob_csf
             print("Renaming prob_csf file")
             rename_prob_csf = pe.Node(niu.Rename(), name = "rename_prob_csf")
-            rename_prob_csf.inputs.format_string = "sub-%(sub)s_ses-%(ses)s_space-{}_label-CSF_probseg".format(space)
-            rename_prob_csf.inputs.parse_string = r"sub-(?P<sub>\w*)_ses-(?P<ses>\w*)_.*"
+            rename_prob_csf.inputs.format_string = pref_deriv + "_space-{}_label-CSF_probseg".format(space)
+            rename_prob_csf.inputs.parse_string = parse_str
             rename_prob_csf.inputs.keep_ext = True
 
             main_workflow.connect(
@@ -649,8 +658,8 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
                 print("Renaming 5tt file")
 
                 rename_gen_5tt = pe.Node(niu.Rename(), name = "rename_gen_5tt")
-                rename_gen_5tt.inputs.format_string = "sub-%(sub)s_ses-%(ses)s_space-{}_desc-5tt_dseg".format(space)
-                rename_gen_5tt.inputs.parse_string = r"sub-(?P<sub>\w*)_ses-(?P<ses>\w*)_.*"
+                rename_gen_5tt.inputs.format_string = pref_deriv + "_space-{}_desc-5tt_dseg".format(space)
+                rename_gen_5tt.inputs.parse_string = parse_str
                 rename_gen_5tt.inputs.keep_ext = True
 
                 main_workflow.connect(
@@ -661,6 +670,88 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
                     rename_gen_5tt, 'out_file',
                     datasink, '@gen_5tt')
 
+        elif "old_segment_pipe" in params.keys():
+
+            ### rename prob_wm
+            print("Renaming prob_wm file")
+            rename_prob_wm = pe.Node(niu.Rename(), name = "rename_prob_wm")
+            rename_prob_wm.inputs.format_string = pref_deriv + "_space-{}_label-WM_probseg".format(space)
+            rename_prob_wm.inputs.parse_string = parse_str
+            rename_prob_wm.inputs.keep_ext = True
+
+            main_workflow.connect(
+                segment_pnh_pipe, 'outputnode.prob_wm',
+                rename_prob_wm, 'in_file')
+
+            main_workflow.connect(
+                rename_prob_wm, ('out_file', show_files),
+                datasink, '@prob_wm')
+
+            ### rename prob_gm
+            print("Renaming prob_gm file")
+            rename_prob_gm = pe.Node(niu.Rename(), name = "rename_prob_gm")
+            rename_prob_gm.inputs.format_string = pref_deriv + "_space-{}_label-GM_probseg".format(space)
+            rename_prob_gm.inputs.parse_string = parse_str
+            rename_prob_gm.inputs.keep_ext = True
+
+            main_workflow.connect(
+                segment_pnh_pipe, 'outputnode.prob_gm',
+                rename_prob_gm, 'in_file')
+
+            main_workflow.connect(
+                rename_prob_gm, ('out_file', show_files),
+                datasink, '@prob_gm')
+
+            ### rename prob_csf
+            print("Renaming prob_csf file")
+            rename_prob_csf = pe.Node(niu.Rename(), name = "rename_prob_csf")
+            rename_prob_csf.inputs.format_string = pref_deriv + "_space-{}_label-CSF_probseg".format(space)
+            rename_prob_csf.inputs.parse_string = parse_str
+            rename_prob_csf.inputs.keep_ext = True
+
+            main_workflow.connect(
+                segment_pnh_pipe, 'outputnode.prob_csf',
+                rename_prob_csf, 'in_file')
+
+            main_workflow.connect(
+                rename_prob_csf, ('out_file', show_files),
+                datasink, '@prob_csf')
+
+            ## rename 5tt
+            #if "export_5tt_pipe" in params["brain_segment_pipe"]:
+                #print("Renaming 5tt file")
+
+                #rename_gen_5tt = pe.Node(niu.Rename(), name = "rename_gen_5tt")
+                #rename_gen_5tt.inputs.format_string = pref_deriv + "_space-{}_desc-5tt_dseg".format(space)
+                #rename_gen_5tt.inputs.parse_string = parse_str
+                #rename_gen_5tt.inputs.keep_ext = True
+
+                #main_workflow.connect(
+                    #segment_pnh_pipe, 'outputnode.gen_5tt',
+                    #rename_gen_5tt, 'in_file')
+
+                #main_workflow.connect(
+                    #rename_gen_5tt, 'out_file',
+                    #datasink, '@gen_5tt')
+
+
+
+        if "mask_from_seg_pipe" in params.keys():
+
+            ### rename segmented_brain_mask
+            rename_segmented_brain_mask = pe.Node(niu.Rename(), name = "rename_segmented_brain_mask")
+            rename_segmented_brain_mask.inputs.format_string = pref_deriv + "_space-{}_desc-brain_dseg".format(space)
+            rename_segmented_brain_mask.inputs.parse_string = parse_str
+            rename_segmented_brain_mask.inputs.keep_ext = True
+
+            main_workflow.connect(
+                segment_pnh_pipe, 'outputnode.segmented_brain_mask',
+                rename_segmented_brain_mask, 'in_file')
+
+            main_workflow.connect(
+                rename_segmented_brain_mask, 'out_file',
+                datasink, '@segmented_brain_mask')
+
         if 'flair' in ssoft :
 
             main_workflow.connect(
@@ -670,6 +761,21 @@ def create_main_workflow(data_dir, process_dir, soft, species, subjects, session
     main_workflow.write_graph(graph2use="colored")
     main_workflow.config['execution'] = {'remove_unnecessary_outputs': 'false'}
 
+    # saving real params.json
+    real_params_file = op.join(process_dir, wf_name, "real_params.json")
+    with open(real_params_file, 'w+') as fp:
+        json.dump(params, fp)
+
+    if deriv:
+        try:
+            os.makedirs(op.join(process_dir, datasink_name))
+        except OSError:
+            print("process_dir {} already exists".format(process_dir))
+
+        real_params_file = op.join(process_dir, datasink_name, "real_params.json")
+        with open(real_params_file, 'w+') as fp:
+            json.dump(params, fp)
+
     if nprocs is None:
         nprocs = 4
 
@@ -710,15 +816,28 @@ def main():
                         required=False)
     parser.add_argument("-mask", dest="mask_file", type=str,
                         help="precomputed mask file", required=False)
+
+    parser.add_argument("-template_path", dest="template_path", type=str,
+                        help="specifies user-based template path",
+                        required=False)
+
+    parser.add_argument("-template_files", dest="template_files", type=str,
+                        nargs="+", help="specifies user-based template files \
+                            (3 or 5 are possible options)",
+                        required=False)
+
     parser.add_argument("-nprocs", dest="nprocs", type=int,
                         help="number of processes to allocate", required=False)
+
     parser.add_argument("-deriv", dest="deriv", action='store_true',
                         help="output derivatives in BIDS orig directory",
                         required=False)
+
     parser.add_argument("-pad", dest="pad", action='store_true',
                         help="padding mask and seg_mask",
                         required=False)
 
+
     args = parser.parse_args()
 
     # main_workflow
@@ -735,6 +854,8 @@ def main():
         params_file=args.params_file,
         indiv_params_file=args.indiv_params_file,
         mask_file=args.mask_file,
+        template_path=args.template_path,
+        template_files=args.template_files,
         nprocs=args.nprocs,
         deriv=args.deriv,
         pad=args.pad)
